@@ -1,9 +1,11 @@
 import datetime
+from http import HTTPStatus
 from typing import Any, Dict, List, Optional, Union
 
 import httpx
 
-from ...client import Client
+from ... import errors
+from ...client import AuthenticatedClient, Client
 from ...models.list_completed_jobs_response_200_item import ListCompletedJobsResponse200Item
 from ...types import UNSET, Response, Unset
 
@@ -11,7 +13,6 @@ from ...types import UNSET, Response, Unset
 def _get_kwargs(
     workspace: str,
     *,
-    client: Client,
     order_desc: Union[Unset, None, bool] = UNSET,
     created_by: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
@@ -29,10 +30,7 @@ def _get_kwargs(
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
 ) -> Dict[str, Any]:
-    url = "{}/w/{workspace}/jobs/completed/list".format(client.base_url, workspace=workspace)
-
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
+    pass
 
     params: Dict[str, Any] = {}
     params["order_desc"] = order_desc
@@ -79,16 +77,17 @@ def _get_kwargs(
 
     return {
         "method": "get",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
+        "url": "/w/{workspace}/jobs/completed/list".format(
+            workspace=workspace,
+        ),
         "params": params,
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[List[ListCompletedJobsResponse200Item]]:
-    if response.status_code == 200:
+def _parse_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Optional[List["ListCompletedJobsResponse200Item"]]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = []
         _response_200 = response.json()
         for response_200_item_data in _response_200:
@@ -97,22 +96,27 @@ def _parse_response(*, response: httpx.Response) -> Optional[List[ListCompletedJ
             response_200.append(response_200_item)
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(response.status_code, response.content)
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[List[ListCompletedJobsResponse200Item]]:
+def _build_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Response[List["ListCompletedJobsResponse200Item"]]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
 def sync_detailed(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     order_desc: Union[Unset, None, bool] = UNSET,
     created_by: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
@@ -129,8 +133,8 @@ def sync_detailed(
     tag: Union[Unset, None, str] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
-) -> Response[List[ListCompletedJobsResponse200Item]]:
-    """list all available completed jobs
+) -> Response[List["ListCompletedJobsResponse200Item"]]:
+    """list all completed jobs
 
     Args:
         workspace (str):
@@ -151,13 +155,16 @@ def sync_detailed(
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ListCompletedJobsResponse200Item]]
+        Response[List['ListCompletedJobsResponse200Item']]
     """
 
     kwargs = _get_kwargs(
         workspace=workspace,
-        client=client,
         order_desc=order_desc,
         created_by=created_by,
         parent_job=parent_job,
@@ -176,18 +183,17 @@ def sync_detailed(
         is_flow_step=is_flow_step,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     order_desc: Union[Unset, None, bool] = UNSET,
     created_by: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
@@ -204,8 +210,8 @@ def sync(
     tag: Union[Unset, None, str] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
-) -> Optional[List[ListCompletedJobsResponse200Item]]:
-    """list all available completed jobs
+) -> Optional[List["ListCompletedJobsResponse200Item"]]:
+    """list all completed jobs
 
     Args:
         workspace (str):
@@ -226,8 +232,12 @@ def sync(
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ListCompletedJobsResponse200Item]]
+        List['ListCompletedJobsResponse200Item']
     """
 
     return sync_detailed(
@@ -255,7 +265,7 @@ def sync(
 async def asyncio_detailed(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     order_desc: Union[Unset, None, bool] = UNSET,
     created_by: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
@@ -272,8 +282,8 @@ async def asyncio_detailed(
     tag: Union[Unset, None, str] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
-) -> Response[List[ListCompletedJobsResponse200Item]]:
-    """list all available completed jobs
+) -> Response[List["ListCompletedJobsResponse200Item"]]:
+    """list all completed jobs
 
     Args:
         workspace (str):
@@ -294,13 +304,16 @@ async def asyncio_detailed(
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ListCompletedJobsResponse200Item]]
+        Response[List['ListCompletedJobsResponse200Item']]
     """
 
     kwargs = _get_kwargs(
         workspace=workspace,
-        client=client,
         order_desc=order_desc,
         created_by=created_by,
         parent_job=parent_job,
@@ -319,16 +332,15 @@ async def asyncio_detailed(
         is_flow_step=is_flow_step,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     order_desc: Union[Unset, None, bool] = UNSET,
     created_by: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
@@ -345,8 +357,8 @@ async def asyncio(
     tag: Union[Unset, None, str] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
-) -> Optional[List[ListCompletedJobsResponse200Item]]:
-    """list all available completed jobs
+) -> Optional[List["ListCompletedJobsResponse200Item"]]:
+    """list all completed jobs
 
     Args:
         workspace (str):
@@ -367,8 +379,12 @@ async def asyncio(
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ListCompletedJobsResponse200Item]]
+        List['ListCompletedJobsResponse200Item']
     """
 
     return (
