@@ -23,6 +23,7 @@ def _get_kwargs(
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
     created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
+    scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
     created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     args: Union[Unset, None, str] = UNSET,
@@ -67,6 +68,8 @@ def _get_kwargs(
 
     params["running"] = running
 
+    params["scheduled_for_before_now"] = scheduled_for_before_now
+
     json_created_or_started_after: Union[Unset, None, str] = UNSET
     if not isinstance(created_or_started_after, Unset):
         json_created_or_started_after = created_or_started_after.isoformat() if created_or_started_after else None
@@ -141,6 +144,7 @@ def sync_detailed(
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
     created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
+    scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
     created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     args: Union[Unset, None, str] = UNSET,
@@ -164,6 +168,7 @@ def sync_detailed(
         started_after (Union[Unset, None, datetime.datetime]):
         created_or_started_before (Union[Unset, None, datetime.datetime]):
         running (Union[Unset, None, bool]):
+        scheduled_for_before_now (Union[Unset, None, bool]):
         created_or_started_after (Union[Unset, None, datetime.datetime]):
         job_kinds (Union[Unset, None, str]):
         args (Union[Unset, None, str]):
@@ -193,6 +198,7 @@ def sync_detailed(
         started_after=started_after,
         created_or_started_before=created_or_started_before,
         running=running,
+        scheduled_for_before_now=scheduled_for_before_now,
         created_or_started_after=created_or_started_after,
         job_kinds=job_kinds,
         args=args,
@@ -224,6 +230,7 @@ def sync(
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
     created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
+    scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
     created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     args: Union[Unset, None, str] = UNSET,
@@ -247,6 +254,7 @@ def sync(
         started_after (Union[Unset, None, datetime.datetime]):
         created_or_started_before (Union[Unset, None, datetime.datetime]):
         running (Union[Unset, None, bool]):
+        scheduled_for_before_now (Union[Unset, None, bool]):
         created_or_started_after (Union[Unset, None, datetime.datetime]):
         job_kinds (Union[Unset, None, str]):
         args (Union[Unset, None, str]):
@@ -277,6 +285,7 @@ def sync(
         started_after=started_after,
         created_or_started_before=created_or_started_before,
         running=running,
+        scheduled_for_before_now=scheduled_for_before_now,
         created_or_started_after=created_or_started_after,
         job_kinds=job_kinds,
         args=args,
@@ -302,6 +311,7 @@ async def asyncio_detailed(
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
     created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
+    scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
     created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     args: Union[Unset, None, str] = UNSET,
@@ -325,6 +335,7 @@ async def asyncio_detailed(
         started_after (Union[Unset, None, datetime.datetime]):
         created_or_started_before (Union[Unset, None, datetime.datetime]):
         running (Union[Unset, None, bool]):
+        scheduled_for_before_now (Union[Unset, None, bool]):
         created_or_started_after (Union[Unset, None, datetime.datetime]):
         job_kinds (Union[Unset, None, str]):
         args (Union[Unset, None, str]):
@@ -354,6 +365,7 @@ async def asyncio_detailed(
         started_after=started_after,
         created_or_started_before=created_or_started_before,
         running=running,
+        scheduled_for_before_now=scheduled_for_before_now,
         created_or_started_after=created_or_started_after,
         job_kinds=job_kinds,
         args=args,
@@ -383,6 +395,7 @@ async def asyncio(
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
     created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
+    scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
     created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     args: Union[Unset, None, str] = UNSET,
@@ -406,6 +419,7 @@ async def asyncio(
         started_after (Union[Unset, None, datetime.datetime]):
         created_or_started_before (Union[Unset, None, datetime.datetime]):
         running (Union[Unset, None, bool]):
+        scheduled_for_before_now (Union[Unset, None, bool]):
         created_or_started_after (Union[Unset, None, datetime.datetime]):
         job_kinds (Union[Unset, None, str]):
         args (Union[Unset, None, str]):
@@ -437,6 +451,7 @@ async def asyncio(
             started_after=started_after,
             created_or_started_before=created_or_started_before,
             running=running,
+            scheduled_for_before_now=scheduled_for_before_now,
             created_or_started_after=created_or_started_after,
             job_kinds=job_kinds,
             args=args,
