@@ -23,6 +23,7 @@ def _get_kwargs(
     started_before: Union[Unset, None, datetime.datetime] = UNSET,
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
+    scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     suspended: Union[Unset, None, bool] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
@@ -61,6 +62,8 @@ def _get_kwargs(
 
     params["success"] = success
 
+    params["scheduled_for_before_now"] = scheduled_for_before_now
+
     params["job_kinds"] = job_kinds
 
     params["suspended"] = suspended
@@ -127,6 +130,7 @@ def sync_detailed(
     started_before: Union[Unset, None, datetime.datetime] = UNSET,
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
+    scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     suspended: Union[Unset, None, bool] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
@@ -148,6 +152,7 @@ def sync_detailed(
         started_before (Union[Unset, None, datetime.datetime]):
         started_after (Union[Unset, None, datetime.datetime]):
         success (Union[Unset, None, bool]):
+        scheduled_for_before_now (Union[Unset, None, bool]):
         job_kinds (Union[Unset, None, str]):
         suspended (Union[Unset, None, bool]):
         running (Union[Unset, None, bool]):
@@ -175,6 +180,7 @@ def sync_detailed(
         started_before=started_before,
         started_after=started_after,
         success=success,
+        scheduled_for_before_now=scheduled_for_before_now,
         job_kinds=job_kinds,
         suspended=suspended,
         running=running,
@@ -204,6 +210,7 @@ def sync(
     started_before: Union[Unset, None, datetime.datetime] = UNSET,
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
+    scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     suspended: Union[Unset, None, bool] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
@@ -225,6 +232,7 @@ def sync(
         started_before (Union[Unset, None, datetime.datetime]):
         started_after (Union[Unset, None, datetime.datetime]):
         success (Union[Unset, None, bool]):
+        scheduled_for_before_now (Union[Unset, None, bool]):
         job_kinds (Union[Unset, None, str]):
         suspended (Union[Unset, None, bool]):
         running (Union[Unset, None, bool]):
@@ -253,6 +261,7 @@ def sync(
         started_before=started_before,
         started_after=started_after,
         success=success,
+        scheduled_for_before_now=scheduled_for_before_now,
         job_kinds=job_kinds,
         suspended=suspended,
         running=running,
@@ -276,6 +285,7 @@ async def asyncio_detailed(
     started_before: Union[Unset, None, datetime.datetime] = UNSET,
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
+    scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     suspended: Union[Unset, None, bool] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
@@ -297,6 +307,7 @@ async def asyncio_detailed(
         started_before (Union[Unset, None, datetime.datetime]):
         started_after (Union[Unset, None, datetime.datetime]):
         success (Union[Unset, None, bool]):
+        scheduled_for_before_now (Union[Unset, None, bool]):
         job_kinds (Union[Unset, None, str]):
         suspended (Union[Unset, None, bool]):
         running (Union[Unset, None, bool]):
@@ -324,6 +335,7 @@ async def asyncio_detailed(
         started_before=started_before,
         started_after=started_after,
         success=success,
+        scheduled_for_before_now=scheduled_for_before_now,
         job_kinds=job_kinds,
         suspended=suspended,
         running=running,
@@ -351,6 +363,7 @@ async def asyncio(
     started_before: Union[Unset, None, datetime.datetime] = UNSET,
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
+    scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     suspended: Union[Unset, None, bool] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
@@ -372,6 +385,7 @@ async def asyncio(
         started_before (Union[Unset, None, datetime.datetime]):
         started_after (Union[Unset, None, datetime.datetime]):
         success (Union[Unset, None, bool]):
+        scheduled_for_before_now (Union[Unset, None, bool]):
         job_kinds (Union[Unset, None, str]):
         suspended (Union[Unset, None, bool]):
         running (Union[Unset, None, bool]):
@@ -401,6 +415,7 @@ async def asyncio(
             started_before=started_before,
             started_after=started_after,
             success=success,
+            scheduled_for_before_now=scheduled_for_before_now,
             job_kinds=job_kinds,
             suspended=suspended,
             running=running,
