@@ -13,6 +13,7 @@ def _get_kwargs(
     path: str,
     *,
     parent_job: Union[Unset, None, str] = UNSET,
+    tag: Union[Unset, None, str] = UNSET,
     job_id: Union[Unset, None, str] = UNSET,
     include_header: Union[Unset, None, str] = UNSET,
     queue_limit: Union[Unset, None, str] = UNSET,
@@ -23,6 +24,8 @@ def _get_kwargs(
     params: Dict[str, Any] = {}
     params["parent_job"] = parent_job
 
+    params["tag"] = tag
+
     params["job_id"] = job_id
 
     params["include_header"] = include_header
@@ -67,6 +70,7 @@ def sync_detailed(
     *,
     client: Union[AuthenticatedClient, Client],
     parent_job: Union[Unset, None, str] = UNSET,
+    tag: Union[Unset, None, str] = UNSET,
     job_id: Union[Unset, None, str] = UNSET,
     include_header: Union[Unset, None, str] = UNSET,
     queue_limit: Union[Unset, None, str] = UNSET,
@@ -78,6 +82,7 @@ def sync_detailed(
         workspace (str):
         path (str):
         parent_job (Union[Unset, None, str]):
+        tag (Union[Unset, None, str]):
         job_id (Union[Unset, None, str]):
         include_header (Union[Unset, None, str]):
         queue_limit (Union[Unset, None, str]):
@@ -95,6 +100,7 @@ def sync_detailed(
         workspace=workspace,
         path=path,
         parent_job=parent_job,
+        tag=tag,
         job_id=job_id,
         include_header=include_header,
         queue_limit=queue_limit,
@@ -114,6 +120,7 @@ async def asyncio_detailed(
     *,
     client: Union[AuthenticatedClient, Client],
     parent_job: Union[Unset, None, str] = UNSET,
+    tag: Union[Unset, None, str] = UNSET,
     job_id: Union[Unset, None, str] = UNSET,
     include_header: Union[Unset, None, str] = UNSET,
     queue_limit: Union[Unset, None, str] = UNSET,
@@ -125,6 +132,7 @@ async def asyncio_detailed(
         workspace (str):
         path (str):
         parent_job (Union[Unset, None, str]):
+        tag (Union[Unset, None, str]):
         job_id (Union[Unset, None, str]):
         include_header (Union[Unset, None, str]):
         queue_limit (Union[Unset, None, str]):
@@ -142,6 +150,7 @@ async def asyncio_detailed(
         workspace=workspace,
         path=path,
         parent_job=parent_job,
+        tag=tag,
         job_id=job_id,
         include_header=include_header,
         queue_limit=queue_limit,
