@@ -1,45 +1,62 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
-from ..models.branch_all_branches_item_modules_item_mock import BranchAllBranchesItemModulesItemMock
-from ..models.branch_all_branches_item_modules_item_retry import BranchAllBranchesItemModulesItemRetry
-from ..models.branch_all_branches_item_modules_item_sleep_type_0 import BranchAllBranchesItemModulesItemSleepType0
-from ..models.branch_all_branches_item_modules_item_sleep_type_1 import BranchAllBranchesItemModulesItemSleepType1
-from ..models.branch_all_branches_item_modules_item_stop_after_if import BranchAllBranchesItemModulesItemStopAfterIf
-from ..models.branch_all_branches_item_modules_item_suspend import BranchAllBranchesItemModulesItemSuspend
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.branch_all_branches_item_modules_item_mock import BranchAllBranchesItemModulesItemMock
+    from ..models.branch_all_branches_item_modules_item_retry import BranchAllBranchesItemModulesItemRetry
+    from ..models.branch_all_branches_item_modules_item_sleep_type_0 import BranchAllBranchesItemModulesItemSleepType0
+    from ..models.branch_all_branches_item_modules_item_sleep_type_1 import BranchAllBranchesItemModulesItemSleepType1
+    from ..models.branch_all_branches_item_modules_item_stop_after_if import BranchAllBranchesItemModulesItemStopAfterIf
+    from ..models.branch_all_branches_item_modules_item_suspend import BranchAllBranchesItemModulesItemSuspend
+
+
 T = TypeVar("T", bound="BranchAllBranchesItemModulesItem")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class BranchAllBranchesItemModulesItem:
     """
     Attributes:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, BranchAllBranchesItemModulesItemStopAfterIf]):
-        sleep (Union[BranchAllBranchesItemModulesItemSleepType0, BranchAllBranchesItemModulesItemSleepType1, Unset]):
+        sleep (Union['BranchAllBranchesItemModulesItemSleepType0', 'BranchAllBranchesItemModulesItemSleepType1',
+            Unset]):
         cache_ttl (Union[Unset, float]):
+        timeout (Union[Unset, float]):
+        delete_after_use (Union[Unset, bool]):
         summary (Union[Unset, str]):
         mock (Union[Unset, BranchAllBranchesItemModulesItemMock]):
         suspend (Union[Unset, BranchAllBranchesItemModulesItemSuspend]):
+        priority (Union[Unset, float]):
         retry (Union[Unset, BranchAllBranchesItemModulesItemRetry]):
     """
 
     id: str
     value: Any
-    stop_after_if: Union[Unset, BranchAllBranchesItemModulesItemStopAfterIf] = UNSET
-    sleep: Union[BranchAllBranchesItemModulesItemSleepType0, BranchAllBranchesItemModulesItemSleepType1, Unset] = UNSET
+    stop_after_if: Union[Unset, "BranchAllBranchesItemModulesItemStopAfterIf"] = UNSET
+    sleep: Union[
+        "BranchAllBranchesItemModulesItemSleepType0", "BranchAllBranchesItemModulesItemSleepType1", Unset
+    ] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
+    timeout: Union[Unset, float] = UNSET
+    delete_after_use: Union[Unset, bool] = UNSET
     summary: Union[Unset, str] = UNSET
-    mock: Union[Unset, BranchAllBranchesItemModulesItemMock] = UNSET
-    suspend: Union[Unset, BranchAllBranchesItemModulesItemSuspend] = UNSET
-    retry: Union[Unset, BranchAllBranchesItemModulesItemRetry] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    mock: Union[Unset, "BranchAllBranchesItemModulesItemMock"] = UNSET
+    suspend: Union[Unset, "BranchAllBranchesItemModulesItemSuspend"] = UNSET
+    priority: Union[Unset, float] = UNSET
+    retry: Union[Unset, "BranchAllBranchesItemModulesItemRetry"] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.branch_all_branches_item_modules_item_sleep_type_0 import (
+            BranchAllBranchesItemModulesItemSleepType0,
+        )
+
         id = self.id
         value = self.value
         stop_after_if: Union[Unset, Dict[str, Any]] = UNSET
@@ -61,6 +78,8 @@ class BranchAllBranchesItemModulesItem:
                 sleep = self.sleep.to_dict()
 
         cache_ttl = self.cache_ttl
+        timeout = self.timeout
+        delete_after_use = self.delete_after_use
         summary = self.summary
         mock: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.mock, Unset):
@@ -70,6 +89,7 @@ class BranchAllBranchesItemModulesItem:
         if not isinstance(self.suspend, Unset):
             suspend = self.suspend.to_dict()
 
+        priority = self.priority
         retry: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.retry, Unset):
             retry = self.retry.to_dict()
@@ -88,12 +108,18 @@ class BranchAllBranchesItemModulesItem:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
             field_dict["cache_ttl"] = cache_ttl
+        if timeout is not UNSET:
+            field_dict["timeout"] = timeout
+        if delete_after_use is not UNSET:
+            field_dict["delete_after_use"] = delete_after_use
         if summary is not UNSET:
             field_dict["summary"] = summary
         if mock is not UNSET:
             field_dict["mock"] = mock
         if suspend is not UNSET:
             field_dict["suspend"] = suspend
+        if priority is not UNSET:
+            field_dict["priority"] = priority
         if retry is not UNSET:
             field_dict["retry"] = retry
 
@@ -101,6 +127,19 @@ class BranchAllBranchesItemModulesItem:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.branch_all_branches_item_modules_item_mock import BranchAllBranchesItemModulesItemMock
+        from ..models.branch_all_branches_item_modules_item_retry import BranchAllBranchesItemModulesItemRetry
+        from ..models.branch_all_branches_item_modules_item_sleep_type_0 import (
+            BranchAllBranchesItemModulesItemSleepType0,
+        )
+        from ..models.branch_all_branches_item_modules_item_sleep_type_1 import (
+            BranchAllBranchesItemModulesItemSleepType1,
+        )
+        from ..models.branch_all_branches_item_modules_item_stop_after_if import (
+            BranchAllBranchesItemModulesItemStopAfterIf,
+        )
+        from ..models.branch_all_branches_item_modules_item_suspend import BranchAllBranchesItemModulesItemSuspend
+
         d = src_dict.copy()
         id = d.pop("id")
 
@@ -115,7 +154,7 @@ class BranchAllBranchesItemModulesItem:
 
         def _parse_sleep(
             data: object,
-        ) -> Union[BranchAllBranchesItemModulesItemSleepType0, BranchAllBranchesItemModulesItemSleepType1, Unset]:
+        ) -> Union["BranchAllBranchesItemModulesItemSleepType0", "BranchAllBranchesItemModulesItemSleepType1", Unset]:
             if isinstance(data, Unset):
                 return data
             try:
@@ -146,6 +185,10 @@ class BranchAllBranchesItemModulesItem:
 
         cache_ttl = d.pop("cache_ttl", UNSET)
 
+        timeout = d.pop("timeout", UNSET)
+
+        delete_after_use = d.pop("delete_after_use", UNSET)
+
         summary = d.pop("summary", UNSET)
 
         _mock = d.pop("mock", UNSET)
@@ -162,6 +205,8 @@ class BranchAllBranchesItemModulesItem:
         else:
             suspend = BranchAllBranchesItemModulesItemSuspend.from_dict(_suspend)
 
+        priority = d.pop("priority", UNSET)
+
         _retry = d.pop("retry", UNSET)
         retry: Union[Unset, BranchAllBranchesItemModulesItemRetry]
         if isinstance(_retry, Unset):
@@ -175,9 +220,12 @@ class BranchAllBranchesItemModulesItem:
             stop_after_if=stop_after_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
+            timeout=timeout,
+            delete_after_use=delete_after_use,
             summary=summary,
             mock=mock,
             suspend=suspend,
+            priority=priority,
             retry=retry,
         )
 
