@@ -1,45 +1,57 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
-from ..models.branch_one_default_item_mock import BranchOneDefaultItemMock
-from ..models.branch_one_default_item_retry import BranchOneDefaultItemRetry
-from ..models.branch_one_default_item_sleep_type_0 import BranchOneDefaultItemSleepType0
-from ..models.branch_one_default_item_sleep_type_1 import BranchOneDefaultItemSleepType1
-from ..models.branch_one_default_item_stop_after_if import BranchOneDefaultItemStopAfterIf
-from ..models.branch_one_default_item_suspend import BranchOneDefaultItemSuspend
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.branch_one_default_item_mock import BranchOneDefaultItemMock
+    from ..models.branch_one_default_item_retry import BranchOneDefaultItemRetry
+    from ..models.branch_one_default_item_sleep_type_0 import BranchOneDefaultItemSleepType0
+    from ..models.branch_one_default_item_sleep_type_1 import BranchOneDefaultItemSleepType1
+    from ..models.branch_one_default_item_stop_after_if import BranchOneDefaultItemStopAfterIf
+    from ..models.branch_one_default_item_suspend import BranchOneDefaultItemSuspend
+
+
 T = TypeVar("T", bound="BranchOneDefaultItem")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class BranchOneDefaultItem:
     """
     Attributes:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, BranchOneDefaultItemStopAfterIf]):
-        sleep (Union[BranchOneDefaultItemSleepType0, BranchOneDefaultItemSleepType1, Unset]):
+        sleep (Union['BranchOneDefaultItemSleepType0', 'BranchOneDefaultItemSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
+        timeout (Union[Unset, float]):
+        delete_after_use (Union[Unset, bool]):
         summary (Union[Unset, str]):
         mock (Union[Unset, BranchOneDefaultItemMock]):
         suspend (Union[Unset, BranchOneDefaultItemSuspend]):
+        priority (Union[Unset, float]):
         retry (Union[Unset, BranchOneDefaultItemRetry]):
     """
 
     id: str
     value: Any
-    stop_after_if: Union[Unset, BranchOneDefaultItemStopAfterIf] = UNSET
-    sleep: Union[BranchOneDefaultItemSleepType0, BranchOneDefaultItemSleepType1, Unset] = UNSET
+    stop_after_if: Union[Unset, "BranchOneDefaultItemStopAfterIf"] = UNSET
+    sleep: Union["BranchOneDefaultItemSleepType0", "BranchOneDefaultItemSleepType1", Unset] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
+    timeout: Union[Unset, float] = UNSET
+    delete_after_use: Union[Unset, bool] = UNSET
     summary: Union[Unset, str] = UNSET
-    mock: Union[Unset, BranchOneDefaultItemMock] = UNSET
-    suspend: Union[Unset, BranchOneDefaultItemSuspend] = UNSET
-    retry: Union[Unset, BranchOneDefaultItemRetry] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    mock: Union[Unset, "BranchOneDefaultItemMock"] = UNSET
+    suspend: Union[Unset, "BranchOneDefaultItemSuspend"] = UNSET
+    priority: Union[Unset, float] = UNSET
+    retry: Union[Unset, "BranchOneDefaultItemRetry"] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.branch_one_default_item_sleep_type_0 import BranchOneDefaultItemSleepType0
+
         id = self.id
         value = self.value
         stop_after_if: Union[Unset, Dict[str, Any]] = UNSET
@@ -61,6 +73,8 @@ class BranchOneDefaultItem:
                 sleep = self.sleep.to_dict()
 
         cache_ttl = self.cache_ttl
+        timeout = self.timeout
+        delete_after_use = self.delete_after_use
         summary = self.summary
         mock: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.mock, Unset):
@@ -70,6 +84,7 @@ class BranchOneDefaultItem:
         if not isinstance(self.suspend, Unset):
             suspend = self.suspend.to_dict()
 
+        priority = self.priority
         retry: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.retry, Unset):
             retry = self.retry.to_dict()
@@ -88,12 +103,18 @@ class BranchOneDefaultItem:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
             field_dict["cache_ttl"] = cache_ttl
+        if timeout is not UNSET:
+            field_dict["timeout"] = timeout
+        if delete_after_use is not UNSET:
+            field_dict["delete_after_use"] = delete_after_use
         if summary is not UNSET:
             field_dict["summary"] = summary
         if mock is not UNSET:
             field_dict["mock"] = mock
         if suspend is not UNSET:
             field_dict["suspend"] = suspend
+        if priority is not UNSET:
+            field_dict["priority"] = priority
         if retry is not UNSET:
             field_dict["retry"] = retry
 
@@ -101,6 +122,13 @@ class BranchOneDefaultItem:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.branch_one_default_item_mock import BranchOneDefaultItemMock
+        from ..models.branch_one_default_item_retry import BranchOneDefaultItemRetry
+        from ..models.branch_one_default_item_sleep_type_0 import BranchOneDefaultItemSleepType0
+        from ..models.branch_one_default_item_sleep_type_1 import BranchOneDefaultItemSleepType1
+        from ..models.branch_one_default_item_stop_after_if import BranchOneDefaultItemStopAfterIf
+        from ..models.branch_one_default_item_suspend import BranchOneDefaultItemSuspend
+
         d = src_dict.copy()
         id = d.pop("id")
 
@@ -113,7 +141,9 @@ class BranchOneDefaultItem:
         else:
             stop_after_if = BranchOneDefaultItemStopAfterIf.from_dict(_stop_after_if)
 
-        def _parse_sleep(data: object) -> Union[BranchOneDefaultItemSleepType0, BranchOneDefaultItemSleepType1, Unset]:
+        def _parse_sleep(
+            data: object,
+        ) -> Union["BranchOneDefaultItemSleepType0", "BranchOneDefaultItemSleepType1", Unset]:
             if isinstance(data, Unset):
                 return data
             try:
@@ -144,6 +174,10 @@ class BranchOneDefaultItem:
 
         cache_ttl = d.pop("cache_ttl", UNSET)
 
+        timeout = d.pop("timeout", UNSET)
+
+        delete_after_use = d.pop("delete_after_use", UNSET)
+
         summary = d.pop("summary", UNSET)
 
         _mock = d.pop("mock", UNSET)
@@ -160,6 +194,8 @@ class BranchOneDefaultItem:
         else:
             suspend = BranchOneDefaultItemSuspend.from_dict(_suspend)
 
+        priority = d.pop("priority", UNSET)
+
         _retry = d.pop("retry", UNSET)
         retry: Union[Unset, BranchOneDefaultItemRetry]
         if isinstance(_retry, Unset):
@@ -173,9 +209,12 @@ class BranchOneDefaultItem:
             stop_after_if=stop_after_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
+            timeout=timeout,
+            delete_after_use=delete_after_use,
             summary=summary,
             mock=mock,
             suspend=suspend,
+            priority=priority,
             retry=retry,
         )
 
