@@ -9,6 +9,7 @@ if TYPE_CHECKING:
     from ..models.create_schedule_json_body_args import CreateScheduleJsonBodyArgs
     from ..models.create_schedule_json_body_on_failure_extra_args import CreateScheduleJsonBodyOnFailureExtraArgs
     from ..models.create_schedule_json_body_on_recovery_extra_args import CreateScheduleJsonBodyOnRecoveryExtraArgs
+    from ..models.create_schedule_json_body_retry import CreateScheduleJsonBodyRetry
 
 
 T = TypeVar("T", bound="CreateScheduleJsonBody")
@@ -33,6 +34,10 @@ class CreateScheduleJsonBody:
         on_recovery_times (Union[Unset, float]):
         on_recovery_extra_args (Union[Unset, CreateScheduleJsonBodyOnRecoveryExtraArgs]):
         ws_error_handler_muted (Union[Unset, bool]):
+        retry (Union[Unset, CreateScheduleJsonBodyRetry]):
+        no_flow_overlap (Union[Unset, bool]):
+        summary (Union[Unset, str]):
+        tag (Union[Unset, str]):
     """
 
     path: str
@@ -50,6 +55,10 @@ class CreateScheduleJsonBody:
     on_recovery_times: Union[Unset, float] = UNSET
     on_recovery_extra_args: Union[Unset, "CreateScheduleJsonBodyOnRecoveryExtraArgs"] = UNSET
     ws_error_handler_muted: Union[Unset, bool] = UNSET
+    retry: Union[Unset, "CreateScheduleJsonBodyRetry"] = UNSET
+    no_flow_overlap: Union[Unset, bool] = UNSET
+    summary: Union[Unset, str] = UNSET
+    tag: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -75,6 +84,13 @@ class CreateScheduleJsonBody:
             on_recovery_extra_args = self.on_recovery_extra_args.to_dict()
 
         ws_error_handler_muted = self.ws_error_handler_muted
+        retry: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.retry, Unset):
+            retry = self.retry.to_dict()
+
+        no_flow_overlap = self.no_flow_overlap
+        summary = self.summary
+        tag = self.tag
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -106,6 +122,14 @@ class CreateScheduleJsonBody:
             field_dict["on_recovery_extra_args"] = on_recovery_extra_args
         if ws_error_handler_muted is not UNSET:
             field_dict["ws_error_handler_muted"] = ws_error_handler_muted
+        if retry is not UNSET:
+            field_dict["retry"] = retry
+        if no_flow_overlap is not UNSET:
+            field_dict["no_flow_overlap"] = no_flow_overlap
+        if summary is not UNSET:
+            field_dict["summary"] = summary
+        if tag is not UNSET:
+            field_dict["tag"] = tag
 
         return field_dict
 
@@ -114,6 +138,7 @@ class CreateScheduleJsonBody:
         from ..models.create_schedule_json_body_args import CreateScheduleJsonBodyArgs
         from ..models.create_schedule_json_body_on_failure_extra_args import CreateScheduleJsonBodyOnFailureExtraArgs
         from ..models.create_schedule_json_body_on_recovery_extra_args import CreateScheduleJsonBodyOnRecoveryExtraArgs
+        from ..models.create_schedule_json_body_retry import CreateScheduleJsonBodyRetry
 
         d = src_dict.copy()
         path = d.pop("path")
@@ -156,6 +181,19 @@ class CreateScheduleJsonBody:
 
         ws_error_handler_muted = d.pop("ws_error_handler_muted", UNSET)
 
+        _retry = d.pop("retry", UNSET)
+        retry: Union[Unset, CreateScheduleJsonBodyRetry]
+        if isinstance(_retry, Unset):
+            retry = UNSET
+        else:
+            retry = CreateScheduleJsonBodyRetry.from_dict(_retry)
+
+        no_flow_overlap = d.pop("no_flow_overlap", UNSET)
+
+        summary = d.pop("summary", UNSET)
+
+        tag = d.pop("tag", UNSET)
+
         create_schedule_json_body = cls(
             path=path,
             schedule=schedule,
@@ -172,6 +210,10 @@ class CreateScheduleJsonBody:
             on_recovery_times=on_recovery_times,
             on_recovery_extra_args=on_recovery_extra_args,
             ws_error_handler_muted=ws_error_handler_muted,
+            retry=retry,
+            no_flow_overlap=no_flow_overlap,
+            summary=summary,
+            tag=tag,
         )
 
         create_schedule_json_body.additional_properties = d
