@@ -1,16 +1,20 @@
 import datetime
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 from dateutil.parser import isoparse
 
-from ..models.flow_metadata_extra_perms import FlowMetadataExtraPerms
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.flow_metadata_extra_perms import FlowMetadataExtraPerms
+
+
 T = TypeVar("T", bound="FlowMetadata")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class FlowMetadata:
     """
     Attributes:
@@ -23,18 +27,28 @@ class FlowMetadata:
         additional_properties (Union[Unset, bool]):
         starred (Union[Unset, bool]):
         draft_only (Union[Unset, bool]):
+        tag (Union[Unset, str]):
+        ws_error_handler_muted (Union[Unset, bool]):
+        priority (Union[Unset, int]):
+        dedicated_worker (Union[Unset, bool]):
+        timeout (Union[Unset, float]):
     """
 
     path: str
     edited_by: str
     edited_at: datetime.datetime
     archived: bool
-    extra_perms: FlowMetadataExtraPerms
+    extra_perms: "FlowMetadataExtraPerms"
     workspace_id: Union[Unset, str] = UNSET
     additional_properties: Union[Unset, bool] = UNSET
     starred: Union[Unset, bool] = UNSET
     draft_only: Union[Unset, bool] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    tag: Union[Unset, str] = UNSET
+    ws_error_handler_muted: Union[Unset, bool] = UNSET
+    priority: Union[Unset, int] = UNSET
+    dedicated_worker: Union[Unset, bool] = UNSET
+    timeout: Union[Unset, float] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         path = self.path
@@ -48,6 +62,11 @@ class FlowMetadata:
         additional_properties = self.additional_properties
         starred = self.starred
         draft_only = self.draft_only
+        tag = self.tag
+        ws_error_handler_muted = self.ws_error_handler_muted
+        priority = self.priority
+        dedicated_worker = self.dedicated_worker
+        timeout = self.timeout
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -68,11 +87,23 @@ class FlowMetadata:
             field_dict["starred"] = starred
         if draft_only is not UNSET:
             field_dict["draft_only"] = draft_only
+        if tag is not UNSET:
+            field_dict["tag"] = tag
+        if ws_error_handler_muted is not UNSET:
+            field_dict["ws_error_handler_muted"] = ws_error_handler_muted
+        if priority is not UNSET:
+            field_dict["priority"] = priority
+        if dedicated_worker is not UNSET:
+            field_dict["dedicated_worker"] = dedicated_worker
+        if timeout is not UNSET:
+            field_dict["timeout"] = timeout
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.flow_metadata_extra_perms import FlowMetadataExtraPerms
+
         d = src_dict.copy()
         path = d.pop("path")
 
@@ -92,6 +123,16 @@ class FlowMetadata:
 
         draft_only = d.pop("draft_only", UNSET)
 
+        tag = d.pop("tag", UNSET)
+
+        ws_error_handler_muted = d.pop("ws_error_handler_muted", UNSET)
+
+        priority = d.pop("priority", UNSET)
+
+        dedicated_worker = d.pop("dedicated_worker", UNSET)
+
+        timeout = d.pop("timeout", UNSET)
+
         flow_metadata = cls(
             path=path,
             edited_by=edited_by,
@@ -102,6 +143,11 @@ class FlowMetadata:
             additional_properties=additional_properties,
             starred=starred,
             draft_only=draft_only,
+            tag=tag,
+            ws_error_handler_muted=ws_error_handler_muted,
+            priority=priority,
+            dedicated_worker=dedicated_worker,
+            timeout=timeout,
         )
 
         flow_metadata.additional_properties = d
