@@ -2,7 +2,7 @@ from enum import Enum
 
 
 class FlowModuleValue2Type3Type(str, Enum):
-    BRANCHONE = "branchone"
+    FORLOOPFLOW = "forloopflow"
 
     def __str__(self) -> str:
         return str(self.value)
