@@ -2,7 +2,7 @@ from enum import Enum
 
 
 class FlowModuleValue2Type7Type(str, Enum):
-    HTTP = "http"
+    GRAPHQL = "graphql"
 
     def __str__(self) -> str:
         return str(self.value)
