@@ -1,62 +1,76 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
-from ..models.get_flow_by_path_response_200_value_failure_module_mock import (
-    GetFlowByPathResponse200ValueFailureModuleMock,
-)
-from ..models.get_flow_by_path_response_200_value_failure_module_retry import (
-    GetFlowByPathResponse200ValueFailureModuleRetry,
-)
-from ..models.get_flow_by_path_response_200_value_failure_module_sleep_type_0 import (
-    GetFlowByPathResponse200ValueFailureModuleSleepType0,
-)
-from ..models.get_flow_by_path_response_200_value_failure_module_sleep_type_1 import (
-    GetFlowByPathResponse200ValueFailureModuleSleepType1,
-)
-from ..models.get_flow_by_path_response_200_value_failure_module_stop_after_if import (
-    GetFlowByPathResponse200ValueFailureModuleStopAfterIf,
-)
-from ..models.get_flow_by_path_response_200_value_failure_module_suspend import (
-    GetFlowByPathResponse200ValueFailureModuleSuspend,
-)
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.get_flow_by_path_response_200_value_failure_module_mock import (
+        GetFlowByPathResponse200ValueFailureModuleMock,
+    )
+    from ..models.get_flow_by_path_response_200_value_failure_module_retry import (
+        GetFlowByPathResponse200ValueFailureModuleRetry,
+    )
+    from ..models.get_flow_by_path_response_200_value_failure_module_sleep_type_0 import (
+        GetFlowByPathResponse200ValueFailureModuleSleepType0,
+    )
+    from ..models.get_flow_by_path_response_200_value_failure_module_sleep_type_1 import (
+        GetFlowByPathResponse200ValueFailureModuleSleepType1,
+    )
+    from ..models.get_flow_by_path_response_200_value_failure_module_stop_after_if import (
+        GetFlowByPathResponse200ValueFailureModuleStopAfterIf,
+    )
+    from ..models.get_flow_by_path_response_200_value_failure_module_suspend import (
+        GetFlowByPathResponse200ValueFailureModuleSuspend,
+    )
+
+
 T = TypeVar("T", bound="GetFlowByPathResponse200ValueFailureModule")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class GetFlowByPathResponse200ValueFailureModule:
     """
     Attributes:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, GetFlowByPathResponse200ValueFailureModuleStopAfterIf]):
-        sleep (Union[GetFlowByPathResponse200ValueFailureModuleSleepType0,
-            GetFlowByPathResponse200ValueFailureModuleSleepType1, Unset]):
+        sleep (Union['GetFlowByPathResponse200ValueFailureModuleSleepType0',
+            'GetFlowByPathResponse200ValueFailureModuleSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
+        timeout (Union[Unset, float]):
+        delete_after_use (Union[Unset, bool]):
         summary (Union[Unset, str]):
         mock (Union[Unset, GetFlowByPathResponse200ValueFailureModuleMock]):
         suspend (Union[Unset, GetFlowByPathResponse200ValueFailureModuleSuspend]):
+        priority (Union[Unset, float]):
         retry (Union[Unset, GetFlowByPathResponse200ValueFailureModuleRetry]):
     """
 
     id: str
     value: Any
-    stop_after_if: Union[Unset, GetFlowByPathResponse200ValueFailureModuleStopAfterIf] = UNSET
+    stop_after_if: Union[Unset, "GetFlowByPathResponse200ValueFailureModuleStopAfterIf"] = UNSET
     sleep: Union[
-        GetFlowByPathResponse200ValueFailureModuleSleepType0,
-        GetFlowByPathResponse200ValueFailureModuleSleepType1,
+        "GetFlowByPathResponse200ValueFailureModuleSleepType0",
+        "GetFlowByPathResponse200ValueFailureModuleSleepType1",
         Unset,
     ] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
+    timeout: Union[Unset, float] = UNSET
+    delete_after_use: Union[Unset, bool] = UNSET
     summary: Union[Unset, str] = UNSET
-    mock: Union[Unset, GetFlowByPathResponse200ValueFailureModuleMock] = UNSET
-    suspend: Union[Unset, GetFlowByPathResponse200ValueFailureModuleSuspend] = UNSET
-    retry: Union[Unset, GetFlowByPathResponse200ValueFailureModuleRetry] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    mock: Union[Unset, "GetFlowByPathResponse200ValueFailureModuleMock"] = UNSET
+    suspend: Union[Unset, "GetFlowByPathResponse200ValueFailureModuleSuspend"] = UNSET
+    priority: Union[Unset, float] = UNSET
+    retry: Union[Unset, "GetFlowByPathResponse200ValueFailureModuleRetry"] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.get_flow_by_path_response_200_value_failure_module_sleep_type_0 import (
+            GetFlowByPathResponse200ValueFailureModuleSleepType0,
+        )
+
         id = self.id
         value = self.value
         stop_after_if: Union[Unset, Dict[str, Any]] = UNSET
@@ -78,6 +92,8 @@ class GetFlowByPathResponse200ValueFailureModule:
                 sleep = self.sleep.to_dict()
 
         cache_ttl = self.cache_ttl
+        timeout = self.timeout
+        delete_after_use = self.delete_after_use
         summary = self.summary
         mock: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.mock, Unset):
@@ -87,6 +103,7 @@ class GetFlowByPathResponse200ValueFailureModule:
         if not isinstance(self.suspend, Unset):
             suspend = self.suspend.to_dict()
 
+        priority = self.priority
         retry: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.retry, Unset):
             retry = self.retry.to_dict()
@@ -105,12 +122,18 @@ class GetFlowByPathResponse200ValueFailureModule:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
             field_dict["cache_ttl"] = cache_ttl
+        if timeout is not UNSET:
+            field_dict["timeout"] = timeout
+        if delete_after_use is not UNSET:
+            field_dict["delete_after_use"] = delete_after_use
         if summary is not UNSET:
             field_dict["summary"] = summary
         if mock is not UNSET:
             field_dict["mock"] = mock
         if suspend is not UNSET:
             field_dict["suspend"] = suspend
+        if priority is not UNSET:
+            field_dict["priority"] = priority
         if retry is not UNSET:
             field_dict["retry"] = retry
 
@@ -118,6 +141,25 @@ class GetFlowByPathResponse200ValueFailureModule:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.get_flow_by_path_response_200_value_failure_module_mock import (
+            GetFlowByPathResponse200ValueFailureModuleMock,
+        )
+        from ..models.get_flow_by_path_response_200_value_failure_module_retry import (
+            GetFlowByPathResponse200ValueFailureModuleRetry,
+        )
+        from ..models.get_flow_by_path_response_200_value_failure_module_sleep_type_0 import (
+            GetFlowByPathResponse200ValueFailureModuleSleepType0,
+        )
+        from ..models.get_flow_by_path_response_200_value_failure_module_sleep_type_1 import (
+            GetFlowByPathResponse200ValueFailureModuleSleepType1,
+        )
+        from ..models.get_flow_by_path_response_200_value_failure_module_stop_after_if import (
+            GetFlowByPathResponse200ValueFailureModuleStopAfterIf,
+        )
+        from ..models.get_flow_by_path_response_200_value_failure_module_suspend import (
+            GetFlowByPathResponse200ValueFailureModuleSuspend,
+        )
+
         d = src_dict.copy()
         id = d.pop("id")
 
@@ -133,8 +175,8 @@ class GetFlowByPathResponse200ValueFailureModule:
         def _parse_sleep(
             data: object,
         ) -> Union[
-            GetFlowByPathResponse200ValueFailureModuleSleepType0,
-            GetFlowByPathResponse200ValueFailureModuleSleepType1,
+            "GetFlowByPathResponse200ValueFailureModuleSleepType0",
+            "GetFlowByPathResponse200ValueFailureModuleSleepType1",
             Unset,
         ]:
             if isinstance(data, Unset):
@@ -167,6 +209,10 @@ class GetFlowByPathResponse200ValueFailureModule:
 
         cache_ttl = d.pop("cache_ttl", UNSET)
 
+        timeout = d.pop("timeout", UNSET)
+
+        delete_after_use = d.pop("delete_after_use", UNSET)
+
         summary = d.pop("summary", UNSET)
 
         _mock = d.pop("mock", UNSET)
@@ -183,6 +229,8 @@ class GetFlowByPathResponse200ValueFailureModule:
         else:
             suspend = GetFlowByPathResponse200ValueFailureModuleSuspend.from_dict(_suspend)
 
+        priority = d.pop("priority", UNSET)
+
         _retry = d.pop("retry", UNSET)
         retry: Union[Unset, GetFlowByPathResponse200ValueFailureModuleRetry]
         if isinstance(_retry, Unset):
@@ -196,9 +244,12 @@ class GetFlowByPathResponse200ValueFailureModule:
             stop_after_if=stop_after_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
+            timeout=timeout,
+            delete_after_use=delete_after_use,
             summary=summary,
             mock=mock,
             suspend=suspend,
+            priority=priority,
             retry=retry,
         )
 
