@@ -1,58 +1,76 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
-from ..models.get_flow_by_path_response_200_value_modules_item_mock import GetFlowByPathResponse200ValueModulesItemMock
-from ..models.get_flow_by_path_response_200_value_modules_item_retry import (
-    GetFlowByPathResponse200ValueModulesItemRetry,
-)
-from ..models.get_flow_by_path_response_200_value_modules_item_sleep_type_0 import (
-    GetFlowByPathResponse200ValueModulesItemSleepType0,
-)
-from ..models.get_flow_by_path_response_200_value_modules_item_sleep_type_1 import (
-    GetFlowByPathResponse200ValueModulesItemSleepType1,
-)
-from ..models.get_flow_by_path_response_200_value_modules_item_stop_after_if import (
-    GetFlowByPathResponse200ValueModulesItemStopAfterIf,
-)
-from ..models.get_flow_by_path_response_200_value_modules_item_suspend import (
-    GetFlowByPathResponse200ValueModulesItemSuspend,
-)
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.get_flow_by_path_response_200_value_modules_item_mock import (
+        GetFlowByPathResponse200ValueModulesItemMock,
+    )
+    from ..models.get_flow_by_path_response_200_value_modules_item_retry import (
+        GetFlowByPathResponse200ValueModulesItemRetry,
+    )
+    from ..models.get_flow_by_path_response_200_value_modules_item_sleep_type_0 import (
+        GetFlowByPathResponse200ValueModulesItemSleepType0,
+    )
+    from ..models.get_flow_by_path_response_200_value_modules_item_sleep_type_1 import (
+        GetFlowByPathResponse200ValueModulesItemSleepType1,
+    )
+    from ..models.get_flow_by_path_response_200_value_modules_item_stop_after_if import (
+        GetFlowByPathResponse200ValueModulesItemStopAfterIf,
+    )
+    from ..models.get_flow_by_path_response_200_value_modules_item_suspend import (
+        GetFlowByPathResponse200ValueModulesItemSuspend,
+    )
+
+
 T = TypeVar("T", bound="GetFlowByPathResponse200ValueModulesItem")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class GetFlowByPathResponse200ValueModulesItem:
     """
     Attributes:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, GetFlowByPathResponse200ValueModulesItemStopAfterIf]):
-        sleep (Union[GetFlowByPathResponse200ValueModulesItemSleepType0,
-            GetFlowByPathResponse200ValueModulesItemSleepType1, Unset]):
+        sleep (Union['GetFlowByPathResponse200ValueModulesItemSleepType0',
+            'GetFlowByPathResponse200ValueModulesItemSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
+        timeout (Union[Unset, float]):
+        delete_after_use (Union[Unset, bool]):
         summary (Union[Unset, str]):
         mock (Union[Unset, GetFlowByPathResponse200ValueModulesItemMock]):
         suspend (Union[Unset, GetFlowByPathResponse200ValueModulesItemSuspend]):
+        priority (Union[Unset, float]):
         retry (Union[Unset, GetFlowByPathResponse200ValueModulesItemRetry]):
     """
 
     id: str
     value: Any
-    stop_after_if: Union[Unset, GetFlowByPathResponse200ValueModulesItemStopAfterIf] = UNSET
+    stop_after_if: Union[Unset, "GetFlowByPathResponse200ValueModulesItemStopAfterIf"] = UNSET
     sleep: Union[
-        GetFlowByPathResponse200ValueModulesItemSleepType0, GetFlowByPathResponse200ValueModulesItemSleepType1, Unset
+        "GetFlowByPathResponse200ValueModulesItemSleepType0",
+        "GetFlowByPathResponse200ValueModulesItemSleepType1",
+        Unset,
     ] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
+    timeout: Union[Unset, float] = UNSET
+    delete_after_use: Union[Unset, bool] = UNSET
     summary: Union[Unset, str] = UNSET
-    mock: Union[Unset, GetFlowByPathResponse200ValueModulesItemMock] = UNSET
-    suspend: Union[Unset, GetFlowByPathResponse200ValueModulesItemSuspend] = UNSET
-    retry: Union[Unset, GetFlowByPathResponse200ValueModulesItemRetry] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    mock: Union[Unset, "GetFlowByPathResponse200ValueModulesItemMock"] = UNSET
+    suspend: Union[Unset, "GetFlowByPathResponse200ValueModulesItemSuspend"] = UNSET
+    priority: Union[Unset, float] = UNSET
+    retry: Union[Unset, "GetFlowByPathResponse200ValueModulesItemRetry"] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.get_flow_by_path_response_200_value_modules_item_sleep_type_0 import (
+            GetFlowByPathResponse200ValueModulesItemSleepType0,
+        )
+
         id = self.id
         value = self.value
         stop_after_if: Union[Unset, Dict[str, Any]] = UNSET
@@ -74,6 +92,8 @@ class GetFlowByPathResponse200ValueModulesItem:
                 sleep = self.sleep.to_dict()
 
         cache_ttl = self.cache_ttl
+        timeout = self.timeout
+        delete_after_use = self.delete_after_use
         summary = self.summary
         mock: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.mock, Unset):
@@ -83,6 +103,7 @@ class GetFlowByPathResponse200ValueModulesItem:
         if not isinstance(self.suspend, Unset):
             suspend = self.suspend.to_dict()
 
+        priority = self.priority
         retry: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.retry, Unset):
             retry = self.retry.to_dict()
@@ -101,12 +122,18 @@ class GetFlowByPathResponse200ValueModulesItem:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
             field_dict["cache_ttl"] = cache_ttl
+        if timeout is not UNSET:
+            field_dict["timeout"] = timeout
+        if delete_after_use is not UNSET:
+            field_dict["delete_after_use"] = delete_after_use
         if summary is not UNSET:
             field_dict["summary"] = summary
         if mock is not UNSET:
             field_dict["mock"] = mock
         if suspend is not UNSET:
             field_dict["suspend"] = suspend
+        if priority is not UNSET:
+            field_dict["priority"] = priority
         if retry is not UNSET:
             field_dict["retry"] = retry
 
@@ -114,6 +141,25 @@ class GetFlowByPathResponse200ValueModulesItem:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.get_flow_by_path_response_200_value_modules_item_mock import (
+            GetFlowByPathResponse200ValueModulesItemMock,
+        )
+        from ..models.get_flow_by_path_response_200_value_modules_item_retry import (
+            GetFlowByPathResponse200ValueModulesItemRetry,
+        )
+        from ..models.get_flow_by_path_response_200_value_modules_item_sleep_type_0 import (
+            GetFlowByPathResponse200ValueModulesItemSleepType0,
+        )
+        from ..models.get_flow_by_path_response_200_value_modules_item_sleep_type_1 import (
+            GetFlowByPathResponse200ValueModulesItemSleepType1,
+        )
+        from ..models.get_flow_by_path_response_200_value_modules_item_stop_after_if import (
+            GetFlowByPathResponse200ValueModulesItemStopAfterIf,
+        )
+        from ..models.get_flow_by_path_response_200_value_modules_item_suspend import (
+            GetFlowByPathResponse200ValueModulesItemSuspend,
+        )
+
         d = src_dict.copy()
         id = d.pop("id")
 
@@ -129,8 +175,8 @@ class GetFlowByPathResponse200ValueModulesItem:
         def _parse_sleep(
             data: object,
         ) -> Union[
-            GetFlowByPathResponse200ValueModulesItemSleepType0,
-            GetFlowByPathResponse200ValueModulesItemSleepType1,
+            "GetFlowByPathResponse200ValueModulesItemSleepType0",
+            "GetFlowByPathResponse200ValueModulesItemSleepType1",
             Unset,
         ]:
             if isinstance(data, Unset):
@@ -163,6 +209,10 @@ class GetFlowByPathResponse200ValueModulesItem:
 
         cache_ttl = d.pop("cache_ttl", UNSET)
 
+        timeout = d.pop("timeout", UNSET)
+
+        delete_after_use = d.pop("delete_after_use", UNSET)
+
         summary = d.pop("summary", UNSET)
 
         _mock = d.pop("mock", UNSET)
@@ -179,6 +229,8 @@ class GetFlowByPathResponse200ValueModulesItem:
         else:
             suspend = GetFlowByPathResponse200ValueModulesItemSuspend.from_dict(_suspend)
 
+        priority = d.pop("priority", UNSET)
+
         _retry = d.pop("retry", UNSET)
         retry: Union[Unset, GetFlowByPathResponse200ValueModulesItemRetry]
         if isinstance(_retry, Unset):
@@ -192,9 +244,12 @@ class GetFlowByPathResponse200ValueModulesItem:
             stop_after_if=stop_after_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
+            timeout=timeout,
+            delete_after_use=delete_after_use,
             summary=summary,
             mock=mock,
             suspend=suspend,
+            priority=priority,
             retry=retry,
         )
 
