@@ -1,62 +1,76 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
-from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_mock import (
-    GetHubFlowByIdResponse200FlowValueModulesItemMock,
-)
-from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_retry import (
-    GetHubFlowByIdResponse200FlowValueModulesItemRetry,
-)
-from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_sleep_type_0 import (
-    GetHubFlowByIdResponse200FlowValueModulesItemSleepType0,
-)
-from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_sleep_type_1 import (
-    GetHubFlowByIdResponse200FlowValueModulesItemSleepType1,
-)
-from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_stop_after_if import (
-    GetHubFlowByIdResponse200FlowValueModulesItemStopAfterIf,
-)
-from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_suspend import (
-    GetHubFlowByIdResponse200FlowValueModulesItemSuspend,
-)
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_mock import (
+        GetHubFlowByIdResponse200FlowValueModulesItemMock,
+    )
+    from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_retry import (
+        GetHubFlowByIdResponse200FlowValueModulesItemRetry,
+    )
+    from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_sleep_type_0 import (
+        GetHubFlowByIdResponse200FlowValueModulesItemSleepType0,
+    )
+    from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_sleep_type_1 import (
+        GetHubFlowByIdResponse200FlowValueModulesItemSleepType1,
+    )
+    from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_stop_after_if import (
+        GetHubFlowByIdResponse200FlowValueModulesItemStopAfterIf,
+    )
+    from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_suspend import (
+        GetHubFlowByIdResponse200FlowValueModulesItemSuspend,
+    )
+
+
 T = TypeVar("T", bound="GetHubFlowByIdResponse200FlowValueModulesItem")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class GetHubFlowByIdResponse200FlowValueModulesItem:
     """
     Attributes:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, GetHubFlowByIdResponse200FlowValueModulesItemStopAfterIf]):
-        sleep (Union[GetHubFlowByIdResponse200FlowValueModulesItemSleepType0,
-            GetHubFlowByIdResponse200FlowValueModulesItemSleepType1, Unset]):
+        sleep (Union['GetHubFlowByIdResponse200FlowValueModulesItemSleepType0',
+            'GetHubFlowByIdResponse200FlowValueModulesItemSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
+        timeout (Union[Unset, float]):
+        delete_after_use (Union[Unset, bool]):
         summary (Union[Unset, str]):
         mock (Union[Unset, GetHubFlowByIdResponse200FlowValueModulesItemMock]):
         suspend (Union[Unset, GetHubFlowByIdResponse200FlowValueModulesItemSuspend]):
+        priority (Union[Unset, float]):
         retry (Union[Unset, GetHubFlowByIdResponse200FlowValueModulesItemRetry]):
     """
 
     id: str
     value: Any
-    stop_after_if: Union[Unset, GetHubFlowByIdResponse200FlowValueModulesItemStopAfterIf] = UNSET
+    stop_after_if: Union[Unset, "GetHubFlowByIdResponse200FlowValueModulesItemStopAfterIf"] = UNSET
     sleep: Union[
-        GetHubFlowByIdResponse200FlowValueModulesItemSleepType0,
-        GetHubFlowByIdResponse200FlowValueModulesItemSleepType1,
+        "GetHubFlowByIdResponse200FlowValueModulesItemSleepType0",
+        "GetHubFlowByIdResponse200FlowValueModulesItemSleepType1",
         Unset,
     ] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
+    timeout: Union[Unset, float] = UNSET
+    delete_after_use: Union[Unset, bool] = UNSET
     summary: Union[Unset, str] = UNSET
-    mock: Union[Unset, GetHubFlowByIdResponse200FlowValueModulesItemMock] = UNSET
-    suspend: Union[Unset, GetHubFlowByIdResponse200FlowValueModulesItemSuspend] = UNSET
-    retry: Union[Unset, GetHubFlowByIdResponse200FlowValueModulesItemRetry] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    mock: Union[Unset, "GetHubFlowByIdResponse200FlowValueModulesItemMock"] = UNSET
+    suspend: Union[Unset, "GetHubFlowByIdResponse200FlowValueModulesItemSuspend"] = UNSET
+    priority: Union[Unset, float] = UNSET
+    retry: Union[Unset, "GetHubFlowByIdResponse200FlowValueModulesItemRetry"] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_sleep_type_0 import (
+            GetHubFlowByIdResponse200FlowValueModulesItemSleepType0,
+        )
+
         id = self.id
         value = self.value
         stop_after_if: Union[Unset, Dict[str, Any]] = UNSET
@@ -78,6 +92,8 @@ class GetHubFlowByIdResponse200FlowValueModulesItem:
                 sleep = self.sleep.to_dict()
 
         cache_ttl = self.cache_ttl
+        timeout = self.timeout
+        delete_after_use = self.delete_after_use
         summary = self.summary
         mock: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.mock, Unset):
@@ -87,6 +103,7 @@ class GetHubFlowByIdResponse200FlowValueModulesItem:
         if not isinstance(self.suspend, Unset):
             suspend = self.suspend.to_dict()
 
+        priority = self.priority
         retry: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.retry, Unset):
             retry = self.retry.to_dict()
@@ -105,12 +122,18 @@ class GetHubFlowByIdResponse200FlowValueModulesItem:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
             field_dict["cache_ttl"] = cache_ttl
+        if timeout is not UNSET:
+            field_dict["timeout"] = timeout
+        if delete_after_use is not UNSET:
+            field_dict["delete_after_use"] = delete_after_use
         if summary is not UNSET:
             field_dict["summary"] = summary
         if mock is not UNSET:
             field_dict["mock"] = mock
         if suspend is not UNSET:
             field_dict["suspend"] = suspend
+        if priority is not UNSET:
+            field_dict["priority"] = priority
         if retry is not UNSET:
             field_dict["retry"] = retry
 
@@ -118,6 +141,25 @@ class GetHubFlowByIdResponse200FlowValueModulesItem:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_mock import (
+            GetHubFlowByIdResponse200FlowValueModulesItemMock,
+        )
+        from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_retry import (
+            GetHubFlowByIdResponse200FlowValueModulesItemRetry,
+        )
+        from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_sleep_type_0 import (
+            GetHubFlowByIdResponse200FlowValueModulesItemSleepType0,
+        )
+        from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_sleep_type_1 import (
+            GetHubFlowByIdResponse200FlowValueModulesItemSleepType1,
+        )
+        from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_stop_after_if import (
+            GetHubFlowByIdResponse200FlowValueModulesItemStopAfterIf,
+        )
+        from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_suspend import (
+            GetHubFlowByIdResponse200FlowValueModulesItemSuspend,
+        )
+
         d = src_dict.copy()
         id = d.pop("id")
 
@@ -133,8 +175,8 @@ class GetHubFlowByIdResponse200FlowValueModulesItem:
         def _parse_sleep(
             data: object,
         ) -> Union[
-            GetHubFlowByIdResponse200FlowValueModulesItemSleepType0,
-            GetHubFlowByIdResponse200FlowValueModulesItemSleepType1,
+            "GetHubFlowByIdResponse200FlowValueModulesItemSleepType0",
+            "GetHubFlowByIdResponse200FlowValueModulesItemSleepType1",
             Unset,
         ]:
             if isinstance(data, Unset):
@@ -167,6 +209,10 @@ class GetHubFlowByIdResponse200FlowValueModulesItem:
 
         cache_ttl = d.pop("cache_ttl", UNSET)
 
+        timeout = d.pop("timeout", UNSET)
+
+        delete_after_use = d.pop("delete_after_use", UNSET)
+
         summary = d.pop("summary", UNSET)
 
         _mock = d.pop("mock", UNSET)
@@ -183,6 +229,8 @@ class GetHubFlowByIdResponse200FlowValueModulesItem:
         else:
             suspend = GetHubFlowByIdResponse200FlowValueModulesItemSuspend.from_dict(_suspend)
 
+        priority = d.pop("priority", UNSET)
+
         _retry = d.pop("retry", UNSET)
         retry: Union[Unset, GetHubFlowByIdResponse200FlowValueModulesItemRetry]
         if isinstance(_retry, Unset):
@@ -196,9 +244,12 @@ class GetHubFlowByIdResponse200FlowValueModulesItem:
             stop_after_if=stop_after_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
+            timeout=timeout,
+            delete_after_use=delete_after_use,
             summary=summary,
             mock=mock,
             suspend=suspend,
+            priority=priority,
             retry=retry,
         )
 
