@@ -28,7 +28,7 @@ class GetScriptByPathWithDraftResponse200:
         parent_hash (Union[Unset, str]):
         schema (Union[Unset, GetScriptByPathWithDraftResponse200Schema]):
         is_template (Union[Unset, bool]):
-        lock (Union[Unset, List[str]]):
+        lock (Union[Unset, str]):
         kind (Union[Unset, GetScriptByPathWithDraftResponse200Kind]):
         tag (Union[Unset, str]):
         draft_only (Union[Unset, bool]):
@@ -55,7 +55,7 @@ class GetScriptByPathWithDraftResponse200:
     parent_hash: Union[Unset, str] = UNSET
     schema: Union[Unset, "GetScriptByPathWithDraftResponse200Schema"] = UNSET
     is_template: Union[Unset, bool] = UNSET
-    lock: Union[Unset, List[str]] = UNSET
+    lock: Union[Unset, str] = UNSET
     kind: Union[Unset, GetScriptByPathWithDraftResponse200Kind] = UNSET
     tag: Union[Unset, str] = UNSET
     draft_only: Union[Unset, bool] = UNSET
@@ -87,10 +87,7 @@ class GetScriptByPathWithDraftResponse200:
             schema = self.schema.to_dict()
 
         is_template = self.is_template
-        lock: Union[Unset, List[str]] = UNSET
-        if not isinstance(self.lock, Unset):
-            lock = self.lock
-
+        lock = self.lock
         kind: Union[Unset, str] = UNSET
         if not isinstance(self.kind, Unset):
             kind = self.kind.value
@@ -197,7 +194,7 @@ class GetScriptByPathWithDraftResponse200:
 
         is_template = d.pop("is_template", UNSET)
 
-        lock = cast(List[str], d.pop("lock", UNSET))
+        lock = d.pop("lock", UNSET)
 
         _kind = d.pop("kind", UNSET)
         kind: Union[Unset, GetScriptByPathWithDraftResponse200Kind]
