@@ -7,7 +7,7 @@ from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
     from ..models.get_settings_response_200_error_handler_extra_args import GetSettingsResponse200ErrorHandlerExtraArgs
-    from ..models.get_settings_response_200_git_sync import GetSettingsResponse200GitSync
+    from ..models.get_settings_response_200_git_sync_item import GetSettingsResponse200GitSyncItem
     from ..models.get_settings_response_200_large_file_storage import GetSettingsResponse200LargeFileStorage
 
 
@@ -34,7 +34,7 @@ class GetSettingsResponse200:
         error_handler_extra_args (Union[Unset, GetSettingsResponse200ErrorHandlerExtraArgs]):
         error_handler_muted_on_cancel (Union[Unset, bool]):
         large_file_storage (Union[Unset, GetSettingsResponse200LargeFileStorage]):
-        git_sync (Union[Unset, GetSettingsResponse200GitSync]):
+        git_sync (Union[Unset, List['GetSettingsResponse200GitSyncItem']]):
     """
 
     code_completion_enabled: bool
@@ -53,7 +53,7 @@ class GetSettingsResponse200:
     error_handler_extra_args: Union[Unset, "GetSettingsResponse200ErrorHandlerExtraArgs"] = UNSET
     error_handler_muted_on_cancel: Union[Unset, bool] = UNSET
     large_file_storage: Union[Unset, "GetSettingsResponse200LargeFileStorage"] = UNSET
-    git_sync: Union[Unset, "GetSettingsResponse200GitSync"] = UNSET
+    git_sync: Union[Unset, List["GetSettingsResponse200GitSyncItem"]] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -79,9 +79,13 @@ class GetSettingsResponse200:
         if not isinstance(self.large_file_storage, Unset):
             large_file_storage = self.large_file_storage.to_dict()
 
-        git_sync: Union[Unset, Dict[str, Any]] = UNSET
+        git_sync: Union[Unset, List[Dict[str, Any]]] = UNSET
         if not isinstance(self.git_sync, Unset):
-            git_sync = self.git_sync.to_dict()
+            git_sync = []
+            for git_sync_item_data in self.git_sync:
+                git_sync_item = git_sync_item_data.to_dict()
+
+                git_sync.append(git_sync_item)
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -130,7 +134,7 @@ class GetSettingsResponse200:
         from ..models.get_settings_response_200_error_handler_extra_args import (
             GetSettingsResponse200ErrorHandlerExtraArgs,
         )
-        from ..models.get_settings_response_200_git_sync import GetSettingsResponse200GitSync
+        from ..models.get_settings_response_200_git_sync_item import GetSettingsResponse200GitSyncItem
         from ..models.get_settings_response_200_large_file_storage import GetSettingsResponse200LargeFileStorage
 
         d = src_dict.copy()
@@ -176,12 +180,12 @@ class GetSettingsResponse200:
         else:
             large_file_storage = GetSettingsResponse200LargeFileStorage.from_dict(_large_file_storage)
 
+        git_sync = []
         _git_sync = d.pop("git_sync", UNSET)
-        git_sync: Union[Unset, GetSettingsResponse200GitSync]
-        if isinstance(_git_sync, Unset):
-            git_sync = UNSET
-        else:
-            git_sync = GetSettingsResponse200GitSync.from_dict(_git_sync)
+        for git_sync_item_data in _git_sync or []:
+            git_sync_item = GetSettingsResponse200GitSyncItem.from_dict(git_sync_item_data)
+
+            git_sync.append(git_sync_item)
 
         get_settings_response_200 = cls(
             code_completion_enabled=code_completion_enabled,
