@@ -1,20 +1,24 @@
 import datetime
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 from dateutil.parser import isoparse
 
-from ..models.list_completed_jobs_response_200_item_args import ListCompletedJobsResponse200ItemArgs
-from ..models.list_completed_jobs_response_200_item_flow_status import ListCompletedJobsResponse200ItemFlowStatus
 from ..models.list_completed_jobs_response_200_item_job_kind import ListCompletedJobsResponse200ItemJobKind
 from ..models.list_completed_jobs_response_200_item_language import ListCompletedJobsResponse200ItemLanguage
-from ..models.list_completed_jobs_response_200_item_raw_flow import ListCompletedJobsResponse200ItemRawFlow
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.list_completed_jobs_response_200_item_args import ListCompletedJobsResponse200ItemArgs
+    from ..models.list_completed_jobs_response_200_item_flow_status import ListCompletedJobsResponse200ItemFlowStatus
+    from ..models.list_completed_jobs_response_200_item_raw_flow import ListCompletedJobsResponse200ItemRawFlow
+
+
 T = TypeVar("T", bound="ListCompletedJobsResponse200Item")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class ListCompletedJobsResponse200Item:
     """
     Attributes:
@@ -49,6 +53,7 @@ class ListCompletedJobsResponse200Item:
         raw_flow (Union[Unset, ListCompletedJobsResponse200ItemRawFlow]):
         language (Union[Unset, ListCompletedJobsResponse200ItemLanguage]):
         mem_peak (Union[Unset, int]):
+        priority (Union[Unset, int]):
     """
 
     id: str
@@ -69,7 +74,7 @@ class ListCompletedJobsResponse200Item:
     parent_job: Union[Unset, str] = UNSET
     script_path: Union[Unset, str] = UNSET
     script_hash: Union[Unset, str] = UNSET
-    args: Union[Unset, ListCompletedJobsResponse200ItemArgs] = UNSET
+    args: Union[Unset, "ListCompletedJobsResponse200ItemArgs"] = UNSET
     result: Union[Unset, Any] = UNSET
     logs: Union[Unset, str] = UNSET
     deleted: Union[Unset, bool] = UNSET
@@ -77,11 +82,12 @@ class ListCompletedJobsResponse200Item:
     canceled_by: Union[Unset, str] = UNSET
     canceled_reason: Union[Unset, str] = UNSET
     schedule_path: Union[Unset, str] = UNSET
-    flow_status: Union[Unset, ListCompletedJobsResponse200ItemFlowStatus] = UNSET
-    raw_flow: Union[Unset, ListCompletedJobsResponse200ItemRawFlow] = UNSET
+    flow_status: Union[Unset, "ListCompletedJobsResponse200ItemFlowStatus"] = UNSET
+    raw_flow: Union[Unset, "ListCompletedJobsResponse200ItemRawFlow"] = UNSET
     language: Union[Unset, ListCompletedJobsResponse200ItemLanguage] = UNSET
     mem_peak: Union[Unset, int] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    priority: Union[Unset, int] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         id = self.id
@@ -129,6 +135,7 @@ class ListCompletedJobsResponse200Item:
             language = self.language.value
 
         mem_peak = self.mem_peak
+        priority = self.priority
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -182,11 +189,19 @@ class ListCompletedJobsResponse200Item:
             field_dict["language"] = language
         if mem_peak is not UNSET:
             field_dict["mem_peak"] = mem_peak
+        if priority is not UNSET:
+            field_dict["priority"] = priority
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.list_completed_jobs_response_200_item_args import ListCompletedJobsResponse200ItemArgs
+        from ..models.list_completed_jobs_response_200_item_flow_status import (
+            ListCompletedJobsResponse200ItemFlowStatus,
+        )
+        from ..models.list_completed_jobs_response_200_item_raw_flow import ListCompletedJobsResponse200ItemRawFlow
+
         d = src_dict.copy()
         id = d.pop("id")
 
@@ -268,6 +283,8 @@ class ListCompletedJobsResponse200Item:
 
         mem_peak = d.pop("mem_peak", UNSET)
 
+        priority = d.pop("priority", UNSET)
+
         list_completed_jobs_response_200_item = cls(
             id=id,
             created_by=created_by,
@@ -299,6 +316,7 @@ class ListCompletedJobsResponse200Item:
             raw_flow=raw_flow,
             language=language,
             mem_peak=mem_peak,
+            priority=priority,
         )
 
         list_completed_jobs_response_200_item.additional_properties = d
