@@ -1,11 +1,12 @@
 from typing import Any, Dict, List, Type, TypeVar
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
 T = TypeVar("T", bound="ListPendingInvitesResponse200Item")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class ListPendingInvitesResponse200Item:
     """
     Attributes:
@@ -19,7 +20,7 @@ class ListPendingInvitesResponse200Item:
     email: str
     is_admin: bool
     operator: bool
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         workspace_id = self.workspace_id
