@@ -26,7 +26,7 @@ class NewScript:
         parent_hash (Union[Unset, str]):
         schema (Union[Unset, NewScriptSchema]):
         is_template (Union[Unset, bool]):
-        lock (Union[Unset, List[str]]):
+        lock (Union[Unset, str]):
         kind (Union[Unset, NewScriptKind]):
         tag (Union[Unset, str]):
         draft_only (Union[Unset, bool]):
@@ -51,7 +51,7 @@ class NewScript:
     parent_hash: Union[Unset, str] = UNSET
     schema: Union[Unset, "NewScriptSchema"] = UNSET
     is_template: Union[Unset, bool] = UNSET
-    lock: Union[Unset, List[str]] = UNSET
+    lock: Union[Unset, str] = UNSET
     kind: Union[Unset, NewScriptKind] = UNSET
     tag: Union[Unset, str] = UNSET
     draft_only: Union[Unset, bool] = UNSET
@@ -81,10 +81,7 @@ class NewScript:
             schema = self.schema.to_dict()
 
         is_template = self.is_template
-        lock: Union[Unset, List[str]] = UNSET
-        if not isinstance(self.lock, Unset):
-            lock = self.lock
-
+        lock = self.lock
         kind: Union[Unset, str] = UNSET
         if not isinstance(self.kind, Unset):
             kind = self.kind.value
@@ -182,7 +179,7 @@ class NewScript:
 
         is_template = d.pop("is_template", UNSET)
 
-        lock = cast(List[str], d.pop("lock", UNSET))
+        lock = d.pop("lock", UNSET)
 
         _kind = d.pop("kind", UNSET)
         kind: Union[Unset, NewScriptKind]
