@@ -1,45 +1,61 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
-from ..models.open_flow_w_path_value_failure_module_mock import OpenFlowWPathValueFailureModuleMock
-from ..models.open_flow_w_path_value_failure_module_retry import OpenFlowWPathValueFailureModuleRetry
-from ..models.open_flow_w_path_value_failure_module_sleep_type_0 import OpenFlowWPathValueFailureModuleSleepType0
-from ..models.open_flow_w_path_value_failure_module_sleep_type_1 import OpenFlowWPathValueFailureModuleSleepType1
-from ..models.open_flow_w_path_value_failure_module_stop_after_if import OpenFlowWPathValueFailureModuleStopAfterIf
-from ..models.open_flow_w_path_value_failure_module_suspend import OpenFlowWPathValueFailureModuleSuspend
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.open_flow_w_path_value_failure_module_mock import OpenFlowWPathValueFailureModuleMock
+    from ..models.open_flow_w_path_value_failure_module_retry import OpenFlowWPathValueFailureModuleRetry
+    from ..models.open_flow_w_path_value_failure_module_sleep_type_0 import OpenFlowWPathValueFailureModuleSleepType0
+    from ..models.open_flow_w_path_value_failure_module_sleep_type_1 import OpenFlowWPathValueFailureModuleSleepType1
+    from ..models.open_flow_w_path_value_failure_module_stop_after_if import OpenFlowWPathValueFailureModuleStopAfterIf
+    from ..models.open_flow_w_path_value_failure_module_suspend import OpenFlowWPathValueFailureModuleSuspend
+
+
 T = TypeVar("T", bound="OpenFlowWPathValueFailureModule")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class OpenFlowWPathValueFailureModule:
     """
     Attributes:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, OpenFlowWPathValueFailureModuleStopAfterIf]):
-        sleep (Union[OpenFlowWPathValueFailureModuleSleepType0, OpenFlowWPathValueFailureModuleSleepType1, Unset]):
+        sleep (Union['OpenFlowWPathValueFailureModuleSleepType0', 'OpenFlowWPathValueFailureModuleSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
+        timeout (Union[Unset, float]):
+        delete_after_use (Union[Unset, bool]):
         summary (Union[Unset, str]):
         mock (Union[Unset, OpenFlowWPathValueFailureModuleMock]):
         suspend (Union[Unset, OpenFlowWPathValueFailureModuleSuspend]):
+        priority (Union[Unset, float]):
         retry (Union[Unset, OpenFlowWPathValueFailureModuleRetry]):
     """
 
     id: str
     value: Any
-    stop_after_if: Union[Unset, OpenFlowWPathValueFailureModuleStopAfterIf] = UNSET
-    sleep: Union[OpenFlowWPathValueFailureModuleSleepType0, OpenFlowWPathValueFailureModuleSleepType1, Unset] = UNSET
+    stop_after_if: Union[Unset, "OpenFlowWPathValueFailureModuleStopAfterIf"] = UNSET
+    sleep: Union[
+        "OpenFlowWPathValueFailureModuleSleepType0", "OpenFlowWPathValueFailureModuleSleepType1", Unset
+    ] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
+    timeout: Union[Unset, float] = UNSET
+    delete_after_use: Union[Unset, bool] = UNSET
     summary: Union[Unset, str] = UNSET
-    mock: Union[Unset, OpenFlowWPathValueFailureModuleMock] = UNSET
-    suspend: Union[Unset, OpenFlowWPathValueFailureModuleSuspend] = UNSET
-    retry: Union[Unset, OpenFlowWPathValueFailureModuleRetry] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    mock: Union[Unset, "OpenFlowWPathValueFailureModuleMock"] = UNSET
+    suspend: Union[Unset, "OpenFlowWPathValueFailureModuleSuspend"] = UNSET
+    priority: Union[Unset, float] = UNSET
+    retry: Union[Unset, "OpenFlowWPathValueFailureModuleRetry"] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.open_flow_w_path_value_failure_module_sleep_type_0 import (
+            OpenFlowWPathValueFailureModuleSleepType0,
+        )
+
         id = self.id
         value = self.value
         stop_after_if: Union[Unset, Dict[str, Any]] = UNSET
@@ -61,6 +77,8 @@ class OpenFlowWPathValueFailureModule:
                 sleep = self.sleep.to_dict()
 
         cache_ttl = self.cache_ttl
+        timeout = self.timeout
+        delete_after_use = self.delete_after_use
         summary = self.summary
         mock: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.mock, Unset):
@@ -70,6 +88,7 @@ class OpenFlowWPathValueFailureModule:
         if not isinstance(self.suspend, Unset):
             suspend = self.suspend.to_dict()
 
+        priority = self.priority
         retry: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.retry, Unset):
             retry = self.retry.to_dict()
@@ -88,12 +107,18 @@ class OpenFlowWPathValueFailureModule:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
             field_dict["cache_ttl"] = cache_ttl
+        if timeout is not UNSET:
+            field_dict["timeout"] = timeout
+        if delete_after_use is not UNSET:
+            field_dict["delete_after_use"] = delete_after_use
         if summary is not UNSET:
             field_dict["summary"] = summary
         if mock is not UNSET:
             field_dict["mock"] = mock
         if suspend is not UNSET:
             field_dict["suspend"] = suspend
+        if priority is not UNSET:
+            field_dict["priority"] = priority
         if retry is not UNSET:
             field_dict["retry"] = retry
 
@@ -101,6 +126,19 @@ class OpenFlowWPathValueFailureModule:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.open_flow_w_path_value_failure_module_mock import OpenFlowWPathValueFailureModuleMock
+        from ..models.open_flow_w_path_value_failure_module_retry import OpenFlowWPathValueFailureModuleRetry
+        from ..models.open_flow_w_path_value_failure_module_sleep_type_0 import (
+            OpenFlowWPathValueFailureModuleSleepType0,
+        )
+        from ..models.open_flow_w_path_value_failure_module_sleep_type_1 import (
+            OpenFlowWPathValueFailureModuleSleepType1,
+        )
+        from ..models.open_flow_w_path_value_failure_module_stop_after_if import (
+            OpenFlowWPathValueFailureModuleStopAfterIf,
+        )
+        from ..models.open_flow_w_path_value_failure_module_suspend import OpenFlowWPathValueFailureModuleSuspend
+
         d = src_dict.copy()
         id = d.pop("id")
 
@@ -115,7 +153,7 @@ class OpenFlowWPathValueFailureModule:
 
         def _parse_sleep(
             data: object,
-        ) -> Union[OpenFlowWPathValueFailureModuleSleepType0, OpenFlowWPathValueFailureModuleSleepType1, Unset]:
+        ) -> Union["OpenFlowWPathValueFailureModuleSleepType0", "OpenFlowWPathValueFailureModuleSleepType1", Unset]:
             if isinstance(data, Unset):
                 return data
             try:
@@ -146,6 +184,10 @@ class OpenFlowWPathValueFailureModule:
 
         cache_ttl = d.pop("cache_ttl", UNSET)
 
+        timeout = d.pop("timeout", UNSET)
+
+        delete_after_use = d.pop("delete_after_use", UNSET)
+
         summary = d.pop("summary", UNSET)
 
         _mock = d.pop("mock", UNSET)
@@ -162,6 +204,8 @@ class OpenFlowWPathValueFailureModule:
         else:
             suspend = OpenFlowWPathValueFailureModuleSuspend.from_dict(_suspend)
 
+        priority = d.pop("priority", UNSET)
+
         _retry = d.pop("retry", UNSET)
         retry: Union[Unset, OpenFlowWPathValueFailureModuleRetry]
         if isinstance(_retry, Unset):
@@ -175,9 +219,12 @@ class OpenFlowWPathValueFailureModule:
             stop_after_if=stop_after_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
+            timeout=timeout,
+            delete_after_use=delete_after_use,
             summary=summary,
             mock=mock,
             suspend=suspend,
+            priority=priority,
             retry=retry,
         )
 
