@@ -1,20 +1,24 @@
 import datetime
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 from dateutil.parser import isoparse
 
-from ..models.queued_job_args import QueuedJobArgs
-from ..models.queued_job_flow_status import QueuedJobFlowStatus
 from ..models.queued_job_job_kind import QueuedJobJobKind
 from ..models.queued_job_language import QueuedJobLanguage
-from ..models.queued_job_raw_flow import QueuedJobRawFlow
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.queued_job_args import QueuedJobArgs
+    from ..models.queued_job_flow_status import QueuedJobFlowStatus
+    from ..models.queued_job_raw_flow import QueuedJobRawFlow
+
+
 T = TypeVar("T", bound="QueuedJob")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class QueuedJob:
     """
     Attributes:
@@ -47,6 +51,7 @@ class QueuedJob:
         raw_flow (Union[Unset, QueuedJobRawFlow]):
         language (Union[Unset, QueuedJobLanguage]):
         mem_peak (Union[Unset, int]):
+        priority (Union[Unset, int]):
     """
 
     id: str
@@ -66,18 +71,19 @@ class QueuedJob:
     scheduled_for: Union[Unset, datetime.datetime] = UNSET
     script_path: Union[Unset, str] = UNSET
     script_hash: Union[Unset, str] = UNSET
-    args: Union[Unset, QueuedJobArgs] = UNSET
+    args: Union[Unset, "QueuedJobArgs"] = UNSET
     logs: Union[Unset, str] = UNSET
     raw_code: Union[Unset, str] = UNSET
     canceled_by: Union[Unset, str] = UNSET
     canceled_reason: Union[Unset, str] = UNSET
     last_ping: Union[Unset, datetime.datetime] = UNSET
     schedule_path: Union[Unset, str] = UNSET
-    flow_status: Union[Unset, QueuedJobFlowStatus] = UNSET
-    raw_flow: Union[Unset, QueuedJobRawFlow] = UNSET
+    flow_status: Union[Unset, "QueuedJobFlowStatus"] = UNSET
+    raw_flow: Union[Unset, "QueuedJobRawFlow"] = UNSET
     language: Union[Unset, QueuedJobLanguage] = UNSET
     mem_peak: Union[Unset, int] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    priority: Union[Unset, int] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         id = self.id
@@ -133,6 +139,7 @@ class QueuedJob:
             language = self.language.value
 
         mem_peak = self.mem_peak
+        priority = self.priority
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -187,11 +194,17 @@ class QueuedJob:
             field_dict["language"] = language
         if mem_peak is not UNSET:
             field_dict["mem_peak"] = mem_peak
+        if priority is not UNSET:
+            field_dict["priority"] = priority
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.queued_job_args import QueuedJobArgs
+        from ..models.queued_job_flow_status import QueuedJobFlowStatus
+        from ..models.queued_job_raw_flow import QueuedJobRawFlow
+
         d = src_dict.copy()
         id = d.pop("id")
 
@@ -289,6 +302,8 @@ class QueuedJob:
 
         mem_peak = d.pop("mem_peak", UNSET)
 
+        priority = d.pop("priority", UNSET)
+
         queued_job = cls(
             id=id,
             running=running,
@@ -318,6 +333,7 @@ class QueuedJob:
             raw_flow=raw_flow,
             language=language,
             mem_peak=mem_peak,
+            priority=priority,
         )
 
         queued_job.additional_properties = d
