@@ -1,54 +1,70 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
-from ..models.run_flow_preview_json_body_value_modules_item_mock import RunFlowPreviewJsonBodyValueModulesItemMock
-from ..models.run_flow_preview_json_body_value_modules_item_retry import RunFlowPreviewJsonBodyValueModulesItemRetry
-from ..models.run_flow_preview_json_body_value_modules_item_sleep_type_0 import (
-    RunFlowPreviewJsonBodyValueModulesItemSleepType0,
-)
-from ..models.run_flow_preview_json_body_value_modules_item_sleep_type_1 import (
-    RunFlowPreviewJsonBodyValueModulesItemSleepType1,
-)
-from ..models.run_flow_preview_json_body_value_modules_item_stop_after_if import (
-    RunFlowPreviewJsonBodyValueModulesItemStopAfterIf,
-)
-from ..models.run_flow_preview_json_body_value_modules_item_suspend import RunFlowPreviewJsonBodyValueModulesItemSuspend
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.run_flow_preview_json_body_value_modules_item_mock import RunFlowPreviewJsonBodyValueModulesItemMock
+    from ..models.run_flow_preview_json_body_value_modules_item_retry import RunFlowPreviewJsonBodyValueModulesItemRetry
+    from ..models.run_flow_preview_json_body_value_modules_item_sleep_type_0 import (
+        RunFlowPreviewJsonBodyValueModulesItemSleepType0,
+    )
+    from ..models.run_flow_preview_json_body_value_modules_item_sleep_type_1 import (
+        RunFlowPreviewJsonBodyValueModulesItemSleepType1,
+    )
+    from ..models.run_flow_preview_json_body_value_modules_item_stop_after_if import (
+        RunFlowPreviewJsonBodyValueModulesItemStopAfterIf,
+    )
+    from ..models.run_flow_preview_json_body_value_modules_item_suspend import (
+        RunFlowPreviewJsonBodyValueModulesItemSuspend,
+    )
+
+
 T = TypeVar("T", bound="RunFlowPreviewJsonBodyValueModulesItem")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class RunFlowPreviewJsonBodyValueModulesItem:
     """
     Attributes:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, RunFlowPreviewJsonBodyValueModulesItemStopAfterIf]):
-        sleep (Union[RunFlowPreviewJsonBodyValueModulesItemSleepType0, RunFlowPreviewJsonBodyValueModulesItemSleepType1,
-            Unset]):
+        sleep (Union['RunFlowPreviewJsonBodyValueModulesItemSleepType0',
+            'RunFlowPreviewJsonBodyValueModulesItemSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
+        timeout (Union[Unset, float]):
+        delete_after_use (Union[Unset, bool]):
         summary (Union[Unset, str]):
         mock (Union[Unset, RunFlowPreviewJsonBodyValueModulesItemMock]):
         suspend (Union[Unset, RunFlowPreviewJsonBodyValueModulesItemSuspend]):
+        priority (Union[Unset, float]):
         retry (Union[Unset, RunFlowPreviewJsonBodyValueModulesItemRetry]):
     """
 
     id: str
     value: Any
-    stop_after_if: Union[Unset, RunFlowPreviewJsonBodyValueModulesItemStopAfterIf] = UNSET
+    stop_after_if: Union[Unset, "RunFlowPreviewJsonBodyValueModulesItemStopAfterIf"] = UNSET
     sleep: Union[
-        RunFlowPreviewJsonBodyValueModulesItemSleepType0, RunFlowPreviewJsonBodyValueModulesItemSleepType1, Unset
+        "RunFlowPreviewJsonBodyValueModulesItemSleepType0", "RunFlowPreviewJsonBodyValueModulesItemSleepType1", Unset
     ] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
+    timeout: Union[Unset, float] = UNSET
+    delete_after_use: Union[Unset, bool] = UNSET
     summary: Union[Unset, str] = UNSET
-    mock: Union[Unset, RunFlowPreviewJsonBodyValueModulesItemMock] = UNSET
-    suspend: Union[Unset, RunFlowPreviewJsonBodyValueModulesItemSuspend] = UNSET
-    retry: Union[Unset, RunFlowPreviewJsonBodyValueModulesItemRetry] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    mock: Union[Unset, "RunFlowPreviewJsonBodyValueModulesItemMock"] = UNSET
+    suspend: Union[Unset, "RunFlowPreviewJsonBodyValueModulesItemSuspend"] = UNSET
+    priority: Union[Unset, float] = UNSET
+    retry: Union[Unset, "RunFlowPreviewJsonBodyValueModulesItemRetry"] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.run_flow_preview_json_body_value_modules_item_sleep_type_0 import (
+            RunFlowPreviewJsonBodyValueModulesItemSleepType0,
+        )
+
         id = self.id
         value = self.value
         stop_after_if: Union[Unset, Dict[str, Any]] = UNSET
@@ -70,6 +86,8 @@ class RunFlowPreviewJsonBodyValueModulesItem:
                 sleep = self.sleep.to_dict()
 
         cache_ttl = self.cache_ttl
+        timeout = self.timeout
+        delete_after_use = self.delete_after_use
         summary = self.summary
         mock: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.mock, Unset):
@@ -79,6 +97,7 @@ class RunFlowPreviewJsonBodyValueModulesItem:
         if not isinstance(self.suspend, Unset):
             suspend = self.suspend.to_dict()
 
+        priority = self.priority
         retry: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.retry, Unset):
             retry = self.retry.to_dict()
@@ -97,12 +116,18 @@ class RunFlowPreviewJsonBodyValueModulesItem:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
             field_dict["cache_ttl"] = cache_ttl
+        if timeout is not UNSET:
+            field_dict["timeout"] = timeout
+        if delete_after_use is not UNSET:
+            field_dict["delete_after_use"] = delete_after_use
         if summary is not UNSET:
             field_dict["summary"] = summary
         if mock is not UNSET:
             field_dict["mock"] = mock
         if suspend is not UNSET:
             field_dict["suspend"] = suspend
+        if priority is not UNSET:
+            field_dict["priority"] = priority
         if retry is not UNSET:
             field_dict["retry"] = retry
 
@@ -110,6 +135,25 @@ class RunFlowPreviewJsonBodyValueModulesItem:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.run_flow_preview_json_body_value_modules_item_mock import (
+            RunFlowPreviewJsonBodyValueModulesItemMock,
+        )
+        from ..models.run_flow_preview_json_body_value_modules_item_retry import (
+            RunFlowPreviewJsonBodyValueModulesItemRetry,
+        )
+        from ..models.run_flow_preview_json_body_value_modules_item_sleep_type_0 import (
+            RunFlowPreviewJsonBodyValueModulesItemSleepType0,
+        )
+        from ..models.run_flow_preview_json_body_value_modules_item_sleep_type_1 import (
+            RunFlowPreviewJsonBodyValueModulesItemSleepType1,
+        )
+        from ..models.run_flow_preview_json_body_value_modules_item_stop_after_if import (
+            RunFlowPreviewJsonBodyValueModulesItemStopAfterIf,
+        )
+        from ..models.run_flow_preview_json_body_value_modules_item_suspend import (
+            RunFlowPreviewJsonBodyValueModulesItemSuspend,
+        )
+
         d = src_dict.copy()
         id = d.pop("id")
 
@@ -125,7 +169,9 @@ class RunFlowPreviewJsonBodyValueModulesItem:
         def _parse_sleep(
             data: object,
         ) -> Union[
-            RunFlowPreviewJsonBodyValueModulesItemSleepType0, RunFlowPreviewJsonBodyValueModulesItemSleepType1, Unset
+            "RunFlowPreviewJsonBodyValueModulesItemSleepType0",
+            "RunFlowPreviewJsonBodyValueModulesItemSleepType1",
+            Unset,
         ]:
             if isinstance(data, Unset):
                 return data
@@ -157,6 +203,10 @@ class RunFlowPreviewJsonBodyValueModulesItem:
 
         cache_ttl = d.pop("cache_ttl", UNSET)
 
+        timeout = d.pop("timeout", UNSET)
+
+        delete_after_use = d.pop("delete_after_use", UNSET)
+
         summary = d.pop("summary", UNSET)
 
         _mock = d.pop("mock", UNSET)
@@ -173,6 +223,8 @@ class RunFlowPreviewJsonBodyValueModulesItem:
         else:
             suspend = RunFlowPreviewJsonBodyValueModulesItemSuspend.from_dict(_suspend)
 
+        priority = d.pop("priority", UNSET)
+
         _retry = d.pop("retry", UNSET)
         retry: Union[Unset, RunFlowPreviewJsonBodyValueModulesItemRetry]
         if isinstance(_retry, Unset):
@@ -186,9 +238,12 @@ class RunFlowPreviewJsonBodyValueModulesItem:
             stop_after_if=stop_after_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
+            timeout=timeout,
+            delete_after_use=delete_after_use,
             summary=summary,
             mock=mock,
             suspend=suspend,
+            priority=priority,
             retry=retry,
         )
 
