@@ -1,13 +1,14 @@
 from typing import Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
 from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="WhoisResponse200Usage")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class WhoisResponse200Usage:
     """
     Attributes:
@@ -15,7 +16,7 @@ class WhoisResponse200Usage:
     """
 
     executions: Union[Unset, float] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         executions = self.executions
